@@ -1,12 +1,14 @@
 "bioenv.formula" <-
-    function(formula, data, ...)
+    function (formula, data, ...) 
 {
+    if (missing(data))
+        data <- parent.frame()
     fla <- formula
     comm <- formula[[2]]
     comm <- eval(comm, data, parent.frame())
     formula[[2]] <- NULL
     mf <- model.frame(formula, data, na.action = na.fail)
-    if (any(sapply(mf, function(x) is.factor(x) || !is.numeric(x))))
+    if (any(sapply(mf, function(x) is.factor(x) || !is.numeric(x)))) 
         stop("bioenv applies only to numeric variables")
     env <- attr(mf, "terms")
     attr(env, "intercept") <- 0
@@ -16,4 +18,3 @@
     out$call <- match.call()
     out
 }
-
