@@ -9,8 +9,6 @@ function (X, dist, pc = TRUE, center = TRUE, halfchange = TRUE,
     if (center) 
         x <- scale(x, scale = FALSE)
     if (pc) {
-        if(!require(mva))
-          stop("PCA rotation requires package `mva'")
         dn <- dimnames(x)
         x <- prcomp(x, center = center)$x
         dimnames(x) <- dn
